aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/app/app.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/app/app.go')
-rw-r--r--internal/app/app.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/internal/app/app.go b/internal/app/app.go
index 325d9f87..902df10f 100644
--- a/internal/app/app.go
+++ b/internal/app/app.go
@@ -5,7 +5,7 @@ import (
"syscall"
"time"
- "git.gensokyo.uk/security/fortify/fst"
+ "git.gensokyo.uk/security/hakurei/hst"
)
type App interface {
@@ -14,7 +14,7 @@ type App interface {
// Seal determines the outcome of config as a [SealedApp].
// The value of config might be overwritten and must not be used again.
- Seal(config *fst.Config) (SealedApp, error)
+ Seal(config *hst.Config) (SealedApp, error)
String() string
}
@@ -48,12 +48,12 @@ func (rs *RunState) SetStart() {
rs.Time = &now
}
// Paths contains environment-dependent paths used by fortify.
type Paths struct {
// path to shared directory (usually `/tmp/fortify.%d`)
SharePath string `json:"share_path"`
// XDG_RUNTIME_DIR value (usually `/run/user/%d`)
RuntimePath string `json:"runtime_path"`
// application runtime directory (usually `/run/user/%d/fortify`)
RunDirPath string `json:"run_dir_path"`
}
@@ -48,12 +48,12 @@ func (rs *RunState) SetStart() {
rs.Time = &now
}
-// Paths contains environment-dependent paths used by fortify.
+// Paths contains environment-dependent paths used by hakurei.
type Paths struct {
@@ -48,12 +48,12 @@ func (rs *RunState) SetStart() {
type Paths struct {
- // path to shared directory (usually `/tmp/fortify.%d`)
+ // path to shared directory (usually `/tmp/hakurei.%d`)
SharePath string `json:"share_path"`
// XDG_RUNTIME_DIR value (usually `/run/user/%d`)
@@ -48,12 +48,12 @@ func (rs *RunState) SetStart() {
// XDG_RUNTIME_DIR value (usually `/run/user/%d`)
RuntimePath string `json:"runtime_path"`
- // application runtime directory (usually `/run/user/%d/fortify`)
+ // application runtime directory (usually `/run/user/%d/hakurei`)
RunDirPath string `json:"run_dir_path"`
}